@@ -2,7 +2,7 @@
 # Patch given file with DATA hunks and print to STDOUT.
 #
 #
-# Patching types in uuidP.h.
+# Patch to localize.
 #
 use strict;
 use warnings;
@@ -28,9 +28,8 @@ print $out;
 exit 0;
 
 __END__
-diff -aurN usrcP/uuid/uuidP.h usrcP.targ/uuid/uuidP.h
---- usrcP/uuid/uuidP.h	2023-12-02 17:58:13.894670000 +0200
-+++ usrcP.targ/uuid/uuidP.h	2023-12-02 15:14:19.716523000 +0200
+--- usrc/uuid/uuidP.h	Wed Nov 29 23:03:41 2023
++++ usrcP/uuid/uuidP.h	Wed Dec  6 00:41:01 2023
 @@ -32,11 +32,7 @@
   * %End-Header%
   */
@@ -43,15 +42,17 @@ diff -aurN usrcP/uuid/uuidP.h usrcP.targ/uuid/uuidP.h
  #include <sys/types.h>
  
  #include <uuid/uuid.h>
-@@ -48,11 +44,11 @@
+@@ -47,12 +43,12 @@
+ #define TIME_OFFSET_HIGH 0x01B21DD2
  #define TIME_OFFSET_LOW  0x13814000
  
- struct uuid {
+-struct uuid {
 -	uint32_t	time_low;
 -	uint16_t	time_mid;
 -	uint16_t	time_hi_and_version;
 -	uint16_t	clock_seq;
 -	uint8_t	node[6];
++struct myuuid {
 +	myuint32_t	time_low;
 +	myuint16_t	time_mid;
 +	myuint16_t	time_hi_and_version;
@@ -60,3 +61,12 @@ diff -aurN usrcP/uuid/uuidP.h usrcP.targ/uuid/uuidP.h
  };
  
  #ifndef __GNUC_PREREQ
+@@ -67,5 +63,5 @@
+ /*
+  * prototypes
+  */
+-void uuid_pack(const struct uuid *uu, uuid_t ptr);
++void myuuid_pack(const struct myuuid *uu, myuuid_t ptr);
+-void uuid_unpack(const uuid_t in, struct uuid *uu);
++void myuuid_unpack(const myuuid_t in, struct myuuid *uu);
+
